#### Admin Menu

Configuration:

This selection launches the multi-tabbed configuration dialog. There are three pages, 'General', 'Jobs', and 'DB Mapping'. The 'General' page options are not currently implemented. They are primarily convenience options and will be available in a future release. The 'Jobs' option is the important one since with it you can configure two default options available for defining and running jobs. The one available during job definition is 'Default Folder Scan Mode", which can be set to either 'Walk' or 'List'. This is only the default option when the Job Definition dialog is started and can be changed in the dialog. The 'Default Run Mode' can also be set here, and again this is only the default and can be changed when a job is selected for running. The two modes available are 'Sequence' and 'Batch' and work as explained for the 'Run" main menu sub menu.

The configuration page 'DB Mapping' is not yet implemented, but the page explains the feature that will be implemented in a future release.

Jobs:

This selection launches the 'Job Definition' dialog. With this dialog you can define jobs to run giving each your selection of files to include and providing each with a unique identifier and a job type. As is true elsewhere in the application, all controls in this dialog have clear tool tips which can be used to understand the features that they control.

When you click the "Add Files' button, the usual file system navigator appears and allowes you to select any number or sequence of files or folders using the mouse with or without the CTRL and SHIFT keys (See the Files menu help tab for details). When you select a folder, only its path is included in the file list but all files in it, scanned according to the 'Scan Mode' you select before launching the navigator, will be present in the file list. When the job is run, the files and folders in it will be processed in the order they appear in in the list.